==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/client/catnip/gui/render/DirectionIndicatorRenderState.java <==
package com.zurrtum.create.client.catnip.gui.render;

import com.mojang.blaze3d.pipeline.RenderPipeline;
import net.minecraft.class_11231;
import net.minecraft.class_11244;
import net.minecraft.class_4588;
import net.minecraft.class_8030;
import org.jetbrains.annotations.Nullable;
import org.joml.Matrix3x2f;

import static com.zurrtum.create.client.catnip.render.PonderRenderPipelines.TRIANGLE_FAN;

public record DirectionIndicatorRenderState(Matrix3x2f pose, float r, float g, float b, class_8030 bounds) implements class_11244 {
    public DirectionIndicatorRenderState(Matrix3x2f pose, float r, float g, float b) {
        this(pose, r, g, b, new class_8030(-5, -5, 10, 5).method_71523(pose));
    }

    @Override
    public RenderPipeline comp_4055() {
        return TRIANGLE_FAN;
    }

    @Override
    public void method_70917(class_4588 vertexConsumer, float depth) {
        vertexConsumer.method_70815(pose, 0, 0, depth).method_22915(r, g, b, 1);
        vertexConsumer.method_70815(pose, 5, -5, depth).method_22915(r, g, b, 0.6f);
        vertexConsumer.method_70815(pose, 3, -4.5f, depth).method_22915(r, g, b, 0.7f);
        vertexConsumer.method_70815(pose, 0, -4.2f, depth).method_22915(r, g, b, 0.7f);
        vertexConsumer.method_70815(pose, -3, -4.5f, depth).method_22915(r, g, b, 0.7f);
        vertexConsumer.method_70815(pose, -5, -5, depth).method_22915(r, g, b, 0.6f);
    }

    @Override
    public class_11231 comp_4056() {
        return class_11231.method_70899();
    }

    @Override
    public @Nullable class_8030 comp_4069() {
        return null;
    }
}

==> create-fly-1.21.10-6.0.8-3-sources.jar: com/zurrtum/create/client/catnip/gui/render/DirectionIndicatorRenderState.java <==
package com.zurrtum.create.client.catnip.gui.render;

import com.mojang.blaze3d.pipeline.RenderPipeline;
import net.minecraft.class_11231;
import net.minecraft.class_11244;
import net.minecraft.class_4588;
import net.minecraft.class_8030;
import org.jetbrains.annotations.Nullable;
import org.joml.Matrix3x2f;

import static com.zurrtum.create.client.catnip.render.PonderRenderPipelines.TRIANGLE_FAN;

public record DirectionIndicatorRenderState(Matrix3x2f pose, float r, float g, float b, class_8030 bounds) implements class_11244 {
    public DirectionIndicatorRenderState(Matrix3x2f pose, float r, float g, float b) {
        this(pose, r, g, b, new class_8030(-5, -5, 10, 5).method_71523(pose));
    }

    @Override
    public RenderPipeline comp_4055() {
        return TRIANGLE_FAN;
    }

    @Override
    public void method_70917(class_4588 vertexConsumer) {
        vertexConsumer.method_70815(pose, 0, 0).method_22915(r, g, b, 1);
        vertexConsumer.method_70815(pose, 5, -5).method_22915(r, g, b, 0.6f);
        vertexConsumer.method_70815(pose, 3, -4.5f).method_22915(r, g, b, 0.7f);
        vertexConsumer.method_70815(pose, 0, -4.2f).method_22915(r, g, b, 0.7f);
        vertexConsumer.method_70815(pose, -3, -4.5f).method_22915(r, g, b, 0.7f);
        vertexConsumer.method_70815(pose, -5, -5).method_22915(r, g, b, 0.6f);
    }

    @Override
    public class_11231 comp_4056() {
        return class_11231.method_70899();
    }

    @Override
    public @Nullable class_8030 comp_4069() {
        return null;
    }
}
